#!/bin/bash

#
# Copyright (c) 2008 Instrumentation Technologies, d.o.o.
# All Rights Reserved.
#
# $Id: LLRF_ARM_upgrade_script.sh 6779 2010-05-13 13:12:56Z primoz.beltram $
#

# TODO: Check Task #939 for additional information and documentation considering MUSTs.
# TODO: maybe put configuration parameters in a different file.
#
# Configuration
#
#   INSTRUMENT_NAME     ... name of the instrument for which the script is made for
#   IPMITOOL_DIR        ... directory where ipmitool is located
#   IPMI_HELP_SCRIPT_DIR  ... directory where ipmitool helper script are located
#   OPENOCD_DIR         ... directory where openocd is located
#   OOCD_HELP_SCRIPT_DIR  ... directory where openocd helper scripts are located
#   LSUSB_DIR           ... directory where lsusb is located
#   OLIMEXTOOL          ... which tool for JTAG programming [ OOJ | OOJT ]
#   FLASH_IMAGES_DIR    ... where the images for flashing are stored.
#


# TODO: put this directories in environment variable PATH

INSTRUMENT_NAME="Libera 1k5k LLRF"
THIS_SCRIPT=$0
IPMITOOL_DIR=/opt/libera/bin
IPMI_HELP_SCRIPT_DIR=/opt/libera/fw/scripts
OPENOCD_DIR=/usr/bin
OOCD_HELP_SCRIPT_DIR=/opt/libera/fw/scripts
LSUSB_DIR=/usr/sbin

#OLIMEXTOOL=OOJ
OLIMEXTOOL=OOJT

ARMCPU=lpc2146
#ARMCPU=lpc2378

# If ARM images are on the current working directory comment the next line
FLASH_IMAGES_DIR=/opt/libera/fw
#FLASH_IMAGES_DIR=$PWD



################################################################################
#
# Global variables set on initialization (parsing)
# some after the upgrade.
#

# Position of the board for FW upgrade
BOARD_POSITION=

# File and its type of the image or file in the command line (ELF or binary)
FW_FILENAME_ARM=
FW_FILE_TYPE=

# Versioning information 
# PRE_* is used for the version read through USB before upgrade
# DUMP_IMAGE_* is used for the version read (parsed) from the dumped image
# POST_* is used for the version read through USB after upgrade
# NEW_* is used for the verion read (parsed) from the file
PRE_BOARD_VERSION=
PRE_SW_VERSION=
PRE_SVN_REPOS_VERSION=

DUMP_IMAGE_BOARD_VERSION=
DUMP_IMAGE_SW_VERSION=
DUMP_IMAGE_SVN_REPOS_VERSION=

POST_BOARD_VERSION=
POST_SW_VERSION=
POST_SVN_REPOS_VERSION=

NEW_BOARD_VERSION=
NEW_SW_VERSION=
NEW_SVN_REPOS_VERSION=

# TODO: add code to check and print additional information.
# TODO: the backup is enabled by deafult
GLOBAL_VERBOSE=0
FORCE_NO_BACKUP=0


################################################################################
# Function definitions
#


function usage1()
{
cat << EOF
Usage: ${0} OPTIONS file

This script upgrades the ARM firmware on chosen satallite position.

OPTIONS:
   -h           Show this message
   -t sat_pos   Which board to upgrade ARM firmware (0-6).
                0 is used for the ICB board.
   -a arm_cpu   Which ARM CPU is in use (ex. lpc2146 or lpc2378)
   -v           Verbose
   file         Image file for flashing (ELF or binary type)
EOF
}


function help()
{
    echo "This is an upgrade script for "${INSTRUMENT_NAME}
    echo "Depends on 3rd party tools:"
    echo -e '\t'"ipmitool, openocd and lsusb"
}

function positions_of_satellites()
{
cat << EOF
    Positions of satellites (Front view):
        .---------------.
        | 0 (ICB) |  |  |
        |---------------|
        |  3  | 1 |  5  |
        |-----+---+-----|
        |  4  | 2 |  6  |
        '---------------'
EOF
}


# Function to create jtag_satellite_onslotX.script if missing

function create_jtag_sattelite_onslot_script()
{
    if [[ $# != 1 ]] || [[ -z $1 ]]; then
        echo "Error in function "${FUNCNAME}": one argument expected"
        echo "Usage:"
        echo -e '\t'${FUNCNAME} " satellite_number"
        exit 1
    fi

cat > ${PWD}/jtag_sattelite_onslot${1}.script << EOF
# script to attach sattelite on ICB slot#${1} to JTAG
# Usage: ipmitool -I bmc exec jtag_sattelite_onslot${1}.script [-vv]

# Power OFF Main+Management ARM on slot #${1}
raw 0 2 0 ${1}
raw 0 2 0 ${1}

# Switch JTAG to ARM on slot #${1}
raw 0 2 0xDC 0x20 0x00 $((${1} - 1)) 0x00

# Power on ARM on slot #${1}
raw 0 2 1 ${1}

# Display Device ID on ICB ARM
#raw 6 1

# Disable JTAG on ICB ARM
#raw 0 2 0x18

# Switch JTAG_SEL_A to HIGH
raw 0 2 0x1A

# Switch JTAG_SEL_L to HIGH
raw 0 2 0x0D

# Trigger ENABLE (aka RESET) on sattelite ARM on slot #${1} to attach to JTAG.
# NOTE: Do it manualy since it must be some delay inbetween!
#ipmitool -I bmc raw 0 2 0xDC 0x1A 0x00 $(( 1 << (${1} - 1))) 0x00
#sleep 5
#ipmitool -I bmc raw 0 2 0xDC 0x1A 0x00 0x00 0x00

EOF
}

function check_tools()
{
    if [ ! -x ${IPMITOOL_DIR}/ipmitool ]; then
        echo "Missing ipmitool!"
        exit 1;
    fi
    if [ ! -x ${OPENOCD_DIR}/openocd ]; then
        echo "Missing openocd!"
        exit 1;
    fi
    if [ ! -x ${LSUSB_DIR}/lsusb ]; then
        echo "Missing lsusb!"
        exit 1;
    fi
}

function check_scripts()
{
# TODO: maybe the next check should be customized to check only the scripts actually needed.

    for test_element in  ${IPMI_HELP_SCRIPT_DIR}/jtag_sattelite_onslot*.script; do
        if [ ! -e ${test_element} ]; then
            echo "Missing IPMI script "${test_element}" needed for switching JTAG switch!"
            exit 1;
        fi
    done
}

function check_ICB_connection()
{
    # First Check if ICB is Connected to USB and if JTAG is connected
    ${LSUSB_DIR}/lsusb -d 1237:abcd 1>/dev/null 2>&1;
    if [ $? != 0 ]; then
        echo "Error: The ICB board is not connected to USB."
        ${LSUSB_DIR}/lsusb -d 15ba: 1>/dev/null 2>&1 && echo -e '\t'"The JTAG cable is plugged in. Please first unplug it and start the script again."
        # TODO: Instead of "exit 1" do the: "Do you want to continue [y/N] =>"
    fi
}

# 
# This function is used for powering down all the satellites by performing
# twice the power_down sequence which ensures that in whatever state the
# the satellites are in they will be shutdown.
#
# Power  --- 1 --> Management   --- 1 --> Full
# Down   <-- 0 --- Power        <-- 0 --- Power
#


function power_up_only_satellite()
{
    if [[ $# != 1 ]]; then
    {
        echo "Error in function "${FUNCNAME}": only one argument expected."
        echo "Usage:"
        echo -e '\t'${FUNCNAME} " satellite_number"
        exit 1
    }
    fi

    if [[ $1 != 0 ]]; then
        for (( i=1; i<=6; i++)); do
            ${IPMITOOL_DIR}/ipmitool -I bmc raw 0 2 0 ${i} 1>/dev/null 2>&1
            ${IPMITOOL_DIR}/ipmitool -I bmc raw 0 2 0 ${i} 1>/dev/null 2>&1
        done

        ${IPMITOOL_DIR}/ipmitool -I bmc raw 0 2 1 ${1} 1>/dev/null 2>&1
    fi
}


####
# Function to parse input command line and set GLOBAL variables
# TODO: 1. check what kind of file it is: Binary or ELF 
#       binary needed only because umage dumping dumps binary
#       2. read from ipmi the register if status connected the satelite
#       
####

function parse_command_line()
{
    if [[ $# == 1 ]]; then
    {
        usage1
        exit 1
    }
    fi

    while getopts “ht:a:vf” OPTION
    do
        case $OPTION in
          h)
              usage1
              exit 1
              ;;
          t)
              BOARD_POSITION=$OPTARG
              ;;
          a)
              ARMCPU=$OPTARG
              ;;
          v)
              GLOBAL_VERBOSE=1
              ;;
          f)
              FORCE_NO_BACKUP=1
              ;;
          \?)
              usage1
              exit
              ;;
          *)
              usage1
              exit
              ;;
        esac
    done

    shift $(($OPTIND - 1))
    FW_FILENAME_ARM=$1

    if [[ -z $BOARD_POSITION ]] || [[ -z $FW_FILENAME_ARM ]]
    then
         usage1
         exit 1
    fi

    # If the absolute path is used than it the file name stays the same
    # otherwise the path to flash images is added to the file name

    # Create an array from the output of command file and we need the information which is
    TEMP_A=(`file ${FLASH_IMAGES_DIR}/${FW_FILENAME_ARM} 2>/dev/null`)

    case ${TEMP_A[1]} in
      "data")
          FW_FILE_TYPE="bin"
          ;;
      "ELF")
          FW_FILE_TYPE="elf"
          ;;
      "directory")
          echo "This is a directory. Please choose a file."
          exit 1
          ;;
      \?)
          false
          ;;
      *)
          false
          ;;
    esac


    if [[ $? != 0 ]]; then
        echo "Error: No such file or directory."
        exit 1
    fi

    # Grep the file to find the vesion information
    TEMP_B=(`strings ${FLASH_IMAGES_DIR}/${FW_FILENAME_ARM} | grep Version`)

    NEW_BOARD_VERSION=${TEMP_B[1]}
    NEW_SW_VERSION=${TEMP_B[4]%.*}
    NEW_SVN_REPOS_VERSION=${TEMP_B[7]}

    if [[ $GLOBAL_VERBOSE == 1 ]]; then

        echo "FILE TYPE: "${FW_FILE_TYPE}
        echo ${TEMP_B[*]}
        echo $NEW_BOARD_VERSION
        echo $NEW_SW_VERSION
        echo $NEW_SVN_REPOS_VERSION
    fi

    if [[ ${BOARD_POSITION} == 0 ]]; then
        TEMP_C=(`${IPMITOOL_DIR}/ipmitool -I bmc raw 6 1`);
    else
        # Ensure that only maintainance voltage is turned on.
        ${IPMITOOL_DIR}/ipmitool -I bmc raw 0 2 0 ${BOARD_POSITION} 1>/dev/null 2>&1
        ${IPMITOOL_DIR}/ipmitool -I bmc raw 0 2 0 ${BOARD_POSITION} 1>/dev/null 2>&1
        ${IPMITOOL_DIR}/ipmitool -I bmc raw 0 2 1 ${BOARD_POSITION} 1>/dev/null 2>&1
        # Added sleep because ARM needs some boot-up time before "up and running"
        sleep 2
        TEMP_C=(`${IPMITOOL_DIR}/ipmitool -I bmc -t ${BOARD_POSITION} raw 6 1 2>/dev/null`);
    fi
# TODO: erase this lines or use them in verbose mode.
    if [[ $GLOBAL_VERBOSE == 1 ]]; then
        echo ${TEMP_C[*]};
        for i in $(seq 0 $(( ${#TEMP_C[*]} -1 ))); do
            echo ${i}" == "${TEMP_C[${i}]}; 
        done;
    fi

    # When the versions are read they are hexadecimal so
    # a transformation to decimal is needed for correct

# from ./pm/shared/platform.h
#    eICB_ID = 0x1C,     /** Interconnection board. */
#    ePCDB1_ID = 0xDB,   /** PC Debug board. */
#    eADC9_ID = 0xAD,    /** ADC9 board. */
#    eVM_ID = 0xEC,    /** Vector Modulator board. */
#    eTCM_ID = 0x1E,     /** Timing board. */
#    eACTL1_ID = 0xAC,     /** ARM Controler board. */
#    eICB1B_ID = 0x2C     /** ICB board rev.B */


    case ${TEMP_C[4]} in
      "1c")
            PRE_BOARD_VERSION=ICB
          ;;
      "db")
            PRE_BOARD_VERSION=PCDB1
          ;;
      "ad")
            PRE_BOARD_VERSION=ADC9
          ;;
      "ec")
            PRE_BOARD_VERSION=VM
          ;;
      "1e")
            PRE_BOARD_VERSION=TCM1
          ;;
      "2e")
            PRE_BOARD_VERSION=TCM1B
          ;;
# TODO: erase this line not needed
#      "ac")
#            PRE_BOARD_VERSION=ACTL1
#          ;;
      "2c")
            PRE_BOARD_VERSION=ICB1B
          ;;
      \?)
            echo "Unknown board."
        # TODO: Instead of "exit 1" do the: "Do you want to continue [y/N] =>"
            ;;
      *)
            echo "Unknown board."
        # TODO: Instead of "exit 1" do the: "Do you want to continue [y/N] =>"
            ;;
    esac

    PRE_SW_VERSION=$((0x${TEMP_C[5]}))
    PRE_SVN_REPOS_VERSION=$((  (0x${TEMP_C[15]} << 24) +  ( 0x${TEMP_C[16]} << 16) +  (0x${TEMP_C[17]} << 8) +  (0x${TEMP_C[18]}) ))

    if [[ $GLOBAL_VERBOSE == 1 ]]; then

        echo $PRE_BOARD_VERSION
        echo $PRE_SW_VERSION
        echo $PRE_SVN_REPOS_VERSION
    fi

    if [[ ${PRE_BOARD_VERSION} != ${NEW_BOARD_VERSION} ]]; then
        echo "The version of the board read "${PRE_BOARD_VERSION}" does not match the version in file "${NEW_BOARD_VERSION}"."
        # TODO: Instead of "exit 1" do the: "Do you want to continue [y/N] =>"
    fi

    if [ ${PRE_SW_VERSION} -le ${NEW_SW_VERSION} ]; then
        echo "Upgrading software from version "${PRE_SW_VERSION}" to "${NEW_SW_VERSION}"."
    else
        echo "Downgrading software from version "${PRE_SW_VERSION}" to "${NEW_SW_VERSION}"."
    fi

    if [ ${PRE_SVN_REPOS_VERSION} -le ${NEW_SVN_REPOS_VERSION} ]; then
        echo "Upgrading from Subversion repository version "${PRE_SVN_REPOS_VERSION}" to "${NEW_SVN_REPOS_VERSION}"."
    else
        echo "Downgrading from Subversion repository version "${PRE_SVN_REPOS_VERSION}" to "${NEW_SVN_REPOS_VERSION}"."
    fi

#    exit 1

}

function verify_dumped_image()
{
    TEMP_D=(`strings  ${PWD}/${PRE_BOARD_VERSION}"_"${PRE_SW_VERSION}"_"${PRE_SVN_REPOS_VERSION}"_"${TEMP_DATE} | grep Version`)

    DUMP_IMAGE_BOARD_VERSION=${TEMP_D[1]}
    DUMP_IMAGE_SW_VERSION=${TEMP_D[4]%.*}
    DUMP_IMAGE_SVN_REPOS_VERSION=${TEMP_D[7]}

    if [[ $GLOBAL_VERBOSE == 1 ]]; then

        echo ${TEMP_D[*]}
        echo "Dumped board: "$DUMP_IMAGE_BOARD_VERSION
        echo "Dumped SW version: "$DUMP_IMAGE_SW_VERSION
        echo "Dumped SVN Revision: "$DUMP_IMAGE_SVN_REPOS_VERSION
    fi
}


function verify_if_finished_correctly()
{

    if [[ ${BOARD_POSITION} == 0 ]]; then
        TEMP_C=(`${IPMITOOL_DIR}/ipmitool -I bmc raw 6 1 2>/dev/null`);
    else
        TEMP_C=(`${IPMITOOL_DIR}/ipmitool -I bmc -t ${BOARD_POSITION} raw 6 1 2>/dev/null`);
    fi
# TODO: erase this lines or use them in verbose mode.
    if [[ $GLOBAL_VERBOSE == 1 ]]; then
        echo ${TEMP_C[*]};
        for i in $(seq 0 $(( ${#TEMP_C[*]} -1 ))); do
            echo ${i}" == "${TEMP_C[${i}]}; 
        done;
    fi

    # When the versions are read they are hexadecimal so
    # a transformation to decimal is needed for correct

# from ./pm/shared/platform.h
#    eICB_ID = 0x1C,     /** Interconnection board. */
#    ePCDB1_ID = 0xDB,   /** PC Debug board. */
#    eADC9_ID = 0xAD,    /** ADC9 board. */
#    eVM_ID = 0xEC,    /** Vector Modulator board. */
#    eTCM_ID = 0x1E,     /** Timing board. */
#    eACTL1_ID = 0xAC,     /** ARM Controler board. */
#    eICB1B_ID = 0x2C     /** ICB board rev.B */


    case ${TEMP_C[4]} in
      "1c")
            POST_BOARD_VERSION=ICB
          ;;
      "db")
            POST_BOARD_VERSION=PCDB1
          ;;
      "ad")
            POST_BOARD_VERSION=ADC9
          ;;
      "ec")
            POST_BOARD_VERSION=VM
          ;;
      "1e")
            PRE_BOARD_VERSION=TCM1
          ;;
      "2e")
            PRE_BOARD_VERSION=TCM1B
          ;;
# TODO: erase this line not needed
#      "ac")
#            POST_BOARD_VERSION=ACTL1
#          ;;
      "2c")
            POST_BOARD_VERSION=ICB1B
          ;;
      \?)
            echo "Unknown board."
        # TODO: Instead of "exit 1" do the: "Do you want to continue [y/N] =>"
            ;;
      *)
            echo "Unknown board."
        # TODO: Instead of "exit 1" do the: "Do you want to continue [y/N] =>"
            ;;
    esac

    POST_SW_VERSION=$((0x${TEMP_C[5]}))
    POST_SVN_REPOS_VERSION=$((  (0x${TEMP_C[15]} << 24) +  ( 0x${TEMP_C[16]} << 16) +  (0x${TEMP_C[17]} << 8) +  (0x${TEMP_C[18]}) ))

    if [[ $GLOBAL_VERBOSE == 1 ]]; then

        echo $POST_BOARD_VERSION
        echo $POST_SW_VERSION
        echo $POST_SVN_REPOS_VERSION
    fi

    if [[ ${POST_BOARD_VERSION} != ${NEW_BOARD_VERSION} ]] || [[ ${POST_SW_VERSION} != ${NEW_SW_VERSION} ]] || [[ ${POST_SVN_REPOS_VERSION} != ${NEW_SVN_REPOS_VERSION} ]]; then
        echo "Upgrade from file: "${FW_FILENAME_ARM}" Failed!"
        echo "The upgraded board read "${POST_BOARD_VERSION}" and in file  "${NEW_BOARD_VERSION}"."
        echo "Software version from board "${POST_SW_VERSION}" and in file "${NEW_SW_VERSION}"."
        echo "Subversion repository version from board "${POST_SVN_REPOS_VERSION}" and Subversion repository version in file "${NEW_SVN_REPOS_VERSION}"."
        # TODO: Instead of "exit 1" do the: "Do you want to continue [y/N] =>"
    else
        echo "Upgrade from file: "${FW_FILENAME_ARM}" Success!"
    fi
}


################################################################################
# TODO: start of shell 
################################################################################
# TODO: check if we have the correct number of attributes

### create_jtag_sattelite_onslot_script ${1}

# TODO: runs on Ubuntu distribution. MUST #6
# TODO: Check if we have all the necessary tools. MUST #5
check_tools
check_scripts
check_ICB_connection

# TODO: before everything is exectured the command line should be parsed
parse_command_line $@

# Before continue shut-down the satellites not used in the upgrade
power_up_only_satellite ${BOARD_POSITION}

# TODO: dont leave this here ... just print it in case -h for help
if [[ $GLOBAL_VERBOSE == 1 ]]; then
    positions_of_satellites
    usage1
fi

## SHIFTNEJ=$1
## echo "Test shift left : " $((1 << (SHIFTNEJ - 1 )))

# Test read from ICB.

${IPMITOOL_DIR}/ipmitool -I bmc raw 6 1 1>/dev/null 2>&1
if [[ $? != 0 ]]; then
    echo "ICB connection with ipmitool failed."
    exit 1
fi

# Test for ADC9 upgrade on slot 3.
# TODO: Dependable on geo_position given on command line.
#       This should be done before connecting the JTAG cable.
# First switch the JTAG switch to position 3 and then disable, wait cca. 20 seconds and enable the sattelite ARM.
# For disable/enable satelite 1 the 0xYY ... hexadecimal number YY=01, for 
#   | 2 YY=02 | 3 YY=04 | 4 YY=08 | 5 YY=10 | 6 YY=20 |

if [[ ${BOARD_POSITION} != 0 ]]; then
    ${IPMITOOL_DIR}/ipmitool -I bmc exec ${IPMI_HELP_SCRIPT_DIR}/jtag_sattelite_onslot${BOARD_POSITION}.script 1>/dev/null 2>&1
fi


${IPMITOOL_DIR}/ipmitool -I bmc raw 0 2 0xDC 0x1A 0x00 $(( 1 << (${BOARD_POSITION} - 1))) 0x00 1>/dev/null 2>&1
sleep 20
${IPMITOOL_DIR}/ipmitool -I bmc raw 0 2 0xDC 0x1A 0x00 0x00 0x00 1>/dev/null 2>&1
sleep 5

# TODO: Before upgrade plug the JTAG cable in
echo -n "Plug the JTAG cable and pres <Enter>: "
read var1

# Create bacup of previous image it is dependant on the ARMCPU used.
if [[ ${ARMCPU} == "lpc2146" ]]; then
    BACKUP_IMAGE_DUMP_SIZE=$(( (1 << 18) -1 ))
elif [[ ${ARMCPU} == "lpc2378" ]]; then
    BACKUP_IMAGE_DUMP_SIZE=$(( (1 << 19) -1 ))
else
    echo "Error: wrong ARM CPU : "${ARMCPU}
    exit 1
fi

# In case we force that there is no backup this lines will be ignored
if [[ $FORCE_NO_BACKUP == 0 ]]; then 
    TEMP_DATE=`date +%Y%m%d%H%M%S`
    ${OPENOCD_DIR}/openocd -f ${OOCD_HELP_SCRIPT_DIR}/${OLIMEXTOOL}_${ARMCPU}_configuration.cfg -c "init" -c "halt" -c "dump_image "${PWD}/${PRE_BOARD_VERSION}"_"${PRE_SW_VERSION}"_"${PRE_SVN_REPOS_VERSION}"_"${TEMP_DATE}" 0 "${BACKUP_IMAGE_DUMP_SIZE} -c "shutdown" || exit 1;
    verify_dumped_image
fi

# Flash the ARM and the verify image
${OPENOCD_DIR}/openocd -f ${OOCD_HELP_SCRIPT_DIR}/${OLIMEXTOOL}_${ARMCPU}_configuration.cfg -f ${OOCD_HELP_SCRIPT_DIR}/${OLIMEXTOOL}_${ARMCPU}_commands.cmd -c "flash write_image "${FLASH_IMAGES_DIR}/${FW_FILENAME_ARM}" 0x0 "${FW_FILE_TYPE} -c "verify_image "${FLASH_IMAGES_DIR}/${FW_FILENAME_ARM}" 0x0 "${FW_FILE_TYPE} -c "mdw 0x0 100" -c "shutdown" || exit 1;

#DELETE: ${OPENOCD_DIR}/openocd -f ${OOCD_HELP_SCRIPT_DIR}/${OLIMEXTOOL}_${ARMCPU}_configuration.cfg -c "init" -c "halt" -c "verify_image "${FLASH_IMAGES_DIR}/${FW_FILENAME_ARM}" 0 "${FW_FILE_TYPE} -c "shutdown" || exit 1;
## -f ${OOCD_HELP_SCRIPT_DIR}/${OLIMEXTOOL}_lpc2146_verification.cmd

# TODO: After upgrade take the JTAG cable out
echo -n "Unplug the JTAG cable and pres <Enter>: "
read var1


# Testing if the upgrade done corectly by turning the board off and then just maintainance power and read (satellites only)

if [[ ${BOARD_POSITION} != 0 ]]; then
    ${IPMITOOL_DIR}/ipmitool -I bmc raw 0 2 0 ${BOARD_POSITION} 1>/dev/null 2>&1
    ${IPMITOOL_DIR}/ipmitool -I bmc raw 0 2 0 ${BOARD_POSITION} 1>/dev/null 2>&1

    ${IPMITOOL_DIR}/ipmitool -I bmc raw 0 2 1 ${BOARD_POSITION} 1>/dev/null 2>&1
fi

# Dodan sleep ker rabi nekaj casa da se ARM postavi
sleep 2

verify_if_finished_correctly

### END OF SCRIPT
